@@ -18,7 +18,7 @@ class Entry:
 
     def parse_tags(self):
         fulltext = " ".join([self.title, self.body]).lower()
-        tags = re.findall(r'(?u)([{tags}]\w+)'.format(tags=self.journal.config['tagsymbols']), fulltext, re.UNICODE)
+        tags = re.findall(r'(?u)\s([{tags}][-+*#/\w]+)'.format(tags=self.journal.config['tagsymbols']), fulltext, re.UNICODE)
         self.tags = tags
         return set(tags)
 
